# Tests are disabled by default because they require network access
%bcond_with tests

Name:           python-virtualenv-api
Version:        2.1.18
Release:        8%{?dist}
Summary:        An API for virtualenv/pip

License:        BSD-2-Clause
URL:            https://github.com/sjkingo/virtualenv-api
# The GitHub tarball contains tests and LICENSE absent from the PyPI sdist.
Source0:        %{url}/archive/%{version}/virtualenv-api-%{version}.tar.gz

BuildArch:      noarch

# Upstream does not name pip and virtualenv as dependencies, but they should
# be. See also:
#   Add virtualenv package to dependencies list
#   https://github.com/sjkingo/virtualenv-api/pull/49
BuildRequires:  /usr/bin/virtualenv
BuildRequires:  /usr/bin/pip

%global common_description %{expand:
virtualenv is a tool to create isolated Python environments. Unfortunately, it
does not expose a native Python API. This package aims to provide an API in the
form of a wrapper around virtualenv.

It can be used to create and delete environments and perform package management
inside the environment.}

%description %{common_description}


%package -n     python%{python3_pkgversion}-virtualenv-api
Summary:        An API for virtualenv/pip
%{?python_provide:%python_provide python%{python3_pkgversion}-virtualenv-api}

BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-six
%if %{with tests}
# It is easier to skip tests when we use pytest as the runner
BuildRequires:  python%{python3_pkgversion}-pytest
%endif

Requires:       python%{python3_pkgversion}-six
Requires:       /usr/bin/virtualenv
Requires:       /usr/bin/pip

%description -n python%{python3_pkgversion}-virtualenv-api %{common_description}


%if 0%{?el7}
%package -n     python2-virtualenv-api
Summary:        An API for virtualenv/pip
%{?python_provide:%python_provide python2-virtualenv-api}

BuildRequires:  python2-setuptools
BuildRequires:  python2-devel
BuildRequires:  python2-six
%if %{with tests}
# It is easier to skip tests when we use pytest as the runner
BuildRequires:  python2-pytest
%endif

Requires:       python2-six
Requires:       /usr/bin/virtualenv
Requires:       /usr/bin/pip

%description -n python2-virtualenv-api %{common_description}
%endif


%prep
%autosetup -n virtualenv-api-%{version}
# Remove bundled egg-info
rm -rf virtualenv-api.egg-info
%if 0%{?el7}
# Work around ascii/UTF-8 default codec issue reading README.rst
sed -r -i "s/'r'\\).read\\(\\)/'rb').read\\(\\).decode\\('utf8'\\)/" setup.py
# Just remove the shebang, rather than trying to make it correct for Python 2
# and Python 3 documentation.
sed -r -i '1{/^#!/d}' example.py
%else
%py3_shebang_fix example.py
%endif


%build
%py3_build
%{?el7:%py2_build}


%install
%py3_install
%{?el7:%py2_install}


%check
%if %{with tests}
# 2.1.18: pytest is failing in four units
# https://github.com/sjkingo/virtualenv-api/issues/55
k="${k-}${k+ and }not test_search"
k="${k-}${k+ and }not test_search_names"
k="${k-}${k+ and }not test_python_version"
k="${k-}${k+ and }not test_no_system_site_packages"
%{python3} -m pytest -v -k "${k-}" tests.py
%{?el7:%{python2} -m pytest -v -k "${k-}" tests.py}
%endif


%files -n python%{python3_pkgversion}-virtualenv-api
%license LICENSE

%doc AUTHORS
%doc CHANGES.md
%doc README.rst
%doc example.py

%{python3_sitelib}/virtualenvapi/
%{python3_sitelib}/virtualenv_api-%{version}-py%{python3_version}.egg-info


%if 0%{?el7}
%files -n python2-virtualenv-api
%license LICENSE

%doc AUTHORS
%doc CHANGES.md
%doc README.rst
%doc example.py

%{python2_sitelib}/virtualenvapi/
%{python2_sitelib}/virtualenv_api-%{version}-py%{python2_version}.egg-info
%endif


%changelog
* Sun Jan 01 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 2.1.18-8
- Switch to GitHub archive with LICENSE and tests
- Update License to SPDX
- Tidy up the spec file a bit; make tests a bcond conditional
- Unicode workaround for EPEL7
- Name the CLI tools in the virtualenv/pip dependencies added downstream
- Reduce macro indirection in the spec file
- Remove bogus BR on git-all
- Package additional documentation files
- Full EPEL7 compatibility with Python 2 and Python3 support
- Skip failing tests for now

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.18-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jun 13 2022 Python Maint <python-maint@redhat.com> - 2.1.18-6
- Rebuilt for Python 3.11

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.18-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Tue Jul 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.18-4
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 2.1.18-3
- Rebuilt for Python 3.10

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.18-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Dec 09 2020 Charalampos Stratakis <cstratak@redhat.com> - 2.1.18-1
- Update to 2.1.18 (rhbz#1797387)

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.16-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 2.1.16-12
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.16-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Oct 03 2019 Miro Hrončok <mhroncok@redhat.com> - 2.1.16-10
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 2.1.16-9
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.16-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Tue Mar 19 2019 Miro Hrončok <mhroncok@redhat.com> - 2.1.16-7
- Subpackage python2-virtualenv-api has been removed
  See https://fedoraproject.org/wiki/Changes/Mass_Python_2_Package_Removal

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.16-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.16-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 2.1.16-4
- Rebuilt for Python 3.7

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.16-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.16-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Mar 20 2017 Michal Cyprian <mcyprian@redhat.com> - 2.1.16-1
- Initial package for EPEL 7.
